@@ -1,4 +1,5 @@
 import traceback
+from .tools import bash_find
 import arrow
 import threading
 from tabulate import tabulate
@@ -101,6 +102,9 @@ def _get_arch():
 @click.option("--images-url", help="default: https://github.com/marcwimmer/odoo")
 @click.option("-I", "--no-update-images", is_flag=True)
 @click.option("-A", "--no-auto-repo", is_flag=True)
+@click.option(
+    "--docker-compose", help="additional docker-compose files, separated by colon :"
+)
 @pass_config
 @click.pass_context
 def do_reload(
@@ -117,6 +121,7 @@ def do_reload(
     images_url,
     no_update_images,
     no_auto_repo,
+    docker_compose,
 ):
     from .myconfigparser import MyConfigParser
 
@@ -162,6 +167,9 @@ def do_reload(
             if "ODOO_DEMO=1\n" in additional_config:
                 demo = True
 
+        if docker_compose:
+            docker_compose = docker_compose.split(":")
+
         internal_reload(
             ctx,
             config,
@@ -173,6 +181,7 @@ def do_reload(
             mailclient_gui_port,
             additional_config,
             apply_auto_repo=not no_auto_repo,
+            additional_docker_configuration_files=docker_compose,
         )
 
     finally:
@@ -196,8 +205,10 @@ def internal_reload(
     mailclient_gui_port,
     additional_config=None,
     apply_auto_repo=True,
+    additional_docker_configuration_files=None,
 ):
     ensure_project_name(config)
+    additional_docker_configuration_files = additional_docker_configuration_files or []
     defaults = {
         "config": config,
         "db": db,
@@ -235,7 +246,10 @@ def internal_reload(
         _apply_autorepo(ctx=ctx, config=config)
 
     # assuming we are in the odoo directory
-    _do_compose(**defaults)
+    _do_compose(
+        **defaults,
+        additional_docker_configuration_files=additional_docker_configuration_files,
+    )
 
     _execute_after_reload(config)
 
@@ -254,7 +268,13 @@ def _set_defaults(config, defaults):
     defaults["project_name"] = config.project_name
 
 
-def _do_compose(config, db="", demo=False, **forced_values):
+def _do_compose(
+    config,
+    db="",
+    demo=False,
+    additional_docker_configuration_files=None,
+    **forced_values,
+):
     """
     builds docker compose, proxy settings, setups odoo instances
     """
@@ -282,7 +302,9 @@ def _do_compose(config, db="", demo=False, **forced_values):
     _prepare_filesystem(config)
     _execute_after_settings(config)
 
-    _prepare_yml_files_from_template_files(config)
+    _prepare_yml_files_from_template_files(
+        config, additional_docker_configuration_files
+    )
 
     click.echo("Built the docker-compose file.")
 
@@ -321,7 +343,6 @@ def _download_images(config, images_url):
     if subprocess.check_output(
         ["git", "remote"], encoding="utf8", cwd=config.dirs["images"]
     ).strip():
-
         trycount = 0
         for i in range(10):
             trycount += 1
@@ -469,7 +490,9 @@ def _execute_after_settings(config):
         settings.write()
 
 
-def _prepare_yml_files_from_template_files(config):
+def _prepare_yml_files_from_template_files(
+    config, additional_docker_configuration_files=None
+):
     # replace params in configuration file
     # replace variables in docker-compose;
     from . import odoo_config
@@ -491,7 +514,8 @@ def _prepare_yml_files_from_template_files(config):
         if dir.is_file():
             _files += [dir]
         else:
-            [_files.append(x) for x in dir.glob("**/docker-compose*.yml")]
+            for file in bash_find(dir, "docker-compose*.yml"):
+                _files.append(file)
 
     if config.restrict and config.restrict.get("docker-compose"):
         _files += config.restrict["docker-compose"]
@@ -514,6 +538,14 @@ def _prepare_yml_files_from_template_files(config):
                     _files.append(x) for x in d.glob("docker-compose*.yml")
                 ]  # not recursive
 
+    if additional_docker_configuration_files:
+        for file in additional_docker_configuration_files:
+            file = Path(os.path.expanduser(file))
+            if not file.exists():
+                raise Exception(f"File {file} does not exist")
+            file = file.absolute()
+            _files += [file]
+
     _files2 = []
     for x in _files:
         if x in _files2:
@@ -565,7 +597,7 @@ def __get_sorted_contents(paths):
 
 
 def __set_environment_in_services(content):
-    for service in content.get("services", []):
+    for service in (content.get("services", []) or []):
         service = content["services"][service]
         service.setdefault("env_file", [])
         if isinstance(service["env_file"], str):
@@ -711,7 +743,6 @@ def dict_merge(dct, merge_dct):
         ):
             dict_merge(dct[k], merge_dct[k])
         else:
-
             # merging lists of tuples and lists
             if k in dct:
                 _make_dict_if_possible(dct, k)
@@ -722,7 +753,7 @@ def dict_merge(dct, merge_dct):
 
 def _prepare_docker_compose_files(config, dest_file, paths):
     from .myconfigparser import MyConfigParser
-    from .tools import abort
+    from .tools import abort, atomic_write
     import yaml
 
     if not dest_file:
@@ -747,12 +778,13 @@ def _prepare_docker_compose_files(config, dest_file, paths):
     content = __run_docker_compose_config(config, contents, env)
     content = post_process_complete_yaml_config(config, content)
     content = _execute_after_compose(config, content)
-    dest_file.write_text(yaml.dump(content, default_flow_style=False))
+    with atomic_write(dest_file) as file:
+        file.write_text(yaml.dump(content, default_flow_style=False))
 
 
 def _fix_contents(contents):
     for content in contents:
-        services = content.get("services")
+        services = content.get("services", []) or []
         for service in services:
             service = services[service]
             # turn {"env_file": {"FILE1": null} --> ["FILE1"]
@@ -777,7 +809,7 @@ def _explode_referenced_machines(contents):
     needs_explosion = {}
 
     for content in contents:
-        for service in content.get("services"):
+        for service in (content.get("services", []) or []):
             labels = content["services"][service].get("labels")
             if labels:
                 if labels.get("compose.merge"):
@@ -786,7 +818,7 @@ def _explode_referenced_machines(contents):
 
     for content in contents:
         for explode, to_explode in needs_explosion.items():
-            if explode in content.get("services", []):
+            if explode in (content.get("services", []) or []):
                 for to_explode in to_explode:
                     if to_explode in content["services"]:
                         src = deepcopy(content["services"][explode])
