@@ -9,7 +9,6 @@ import json
 import base64
 import subprocess
 import inquirer
-from git import Repo
 import traceback
 from datetime import datetime
 import shutil
@@ -19,6 +18,7 @@ import click
 
 from wodoo.robo_helpers import _get_required_odoo_modules_from_robot_file
 from .tools import is_git_clean
+from gimera.repo import Repo
 from .tools import get_hash
 from .tools import get_directory_hash
 from .tools import sync_folder
@@ -262,12 +262,18 @@ def _get_outdated_versioned_modules_of_deptree(modules):
                 odoo_version = str(MANIFEST()["version"]).split(".")
                 assert (
                     len(odoo_version) == 2
-                ), f"Version in manifest should be like 16.0 not '{odoo_version}'"
+                ), f"Version in manifest should be like 16.0 not '{odoo_version}' as it is in {MANIFEST().path}"
                 new_version = tuple(list(map(int, odoo_version)) + list(new_version))
                 del odoo_version
 
             if new_version > version:
-                yield dep
+                # seen: if version in manifest is 14.0.1.0 and installed in
+                # 13.0 odoo then version becomes inside odoo: 13.0.14.0.10
+                # so try to match including current version:
+                odoo_version = list(map(int, str(MANIFEST()['version']).split(".")))
+                new_version = tuple(odoo_version + list(new_version))
+                if new_version != version:
+                    yield dep
 
 
 def _get_available_modules(ctx, param, incomplete):
@@ -1283,29 +1289,43 @@ def _get_changed_files(git_sha):
     filepaths2 = []
     cwd = Path(os.getcwd())
     for filepath in filepaths:
+        filepath = repo.path / filepath
         os.chdir(cwd)
-        submodule = [x for x in repo.submodules if x.path == filepath]
+
+        def get_submodule(filepath):
+            for submodule in repo.get_submodules():
+                try:
+                    filepath.relative_to(submodule.path)
+                    return submodule
+                except ValueError:
+                    continue
+
+        submodule = get_submodule(filepath)
+
         if submodule:
-            current_commit = str(repo.active_branch.commit)
+            current_commit = str(repo.hex)
+            relpath = filepath.relative_to(repo.path)
             old_commit = (
-                subprocess.check_output(["git", "rev-parse", f"{git_sha}:./{filepath}"])
-                .decode("utf-8")
+                subprocess.check_output(
+                    [
+                        "git",
+                        "rev-parse",
+                        f"{git_sha}:./{relpath}",
+                    ], encoding='utf8'
+                )
                 .strip()
             )
             new_commit = (
                 subprocess.check_output(
-                    ["git", "rev-parse", f"{current_commit}:./{filepath}"]
+                    ["git", "rev-parse", f"{current_commit}:./{relpath}"], encoding='utf8',
                 )
-                .decode("utf-8")
                 .strip()
             )
             # now diff the submodule
-            submodule_path = cwd / filepath
-            submodule_relative_path = filepath
-            for filepath2 in git_diff_files(submodule_path, old_commit, new_commit):
-                filepaths2.append(submodule_relative_path + "/" + filepath2)
+            for filepath2 in git_diff_files(filepath, old_commit, new_commit):
+                filepaths2.append(str(relpath / filepath2))
         else:
-            filepaths2.append(filepath)
+            filepaths2.append(str(filepath.relative_to(repo.path)))
 
     return filepaths2
 
@@ -1399,7 +1419,6 @@ def list_deps(ctx, config, module, no_cache):
 
     result = {}
     for module in module:
-
         data = {"modules": []}
         data["modules"] = sorted(
             list(map(lambda x: x.name, modules.get_module_flat_dependency_tree(module)))
@@ -1498,6 +1517,25 @@ def list_modules(ctx, config):
         print(m)
 
 
+@odoo_module.command()
+@pass_config
+@click.pass_context
+def list_outdated_modules(ctx, config):
+    modules = _get_default_modules_to_update()
+
+    def _get_outdated_modules(module):
+        return list(
+            map(
+                lambda x: x.name,
+                set(_get_outdated_versioned_modules_of_deptree(module)),
+            )
+        )
+
+    print("---")
+    for mod2 in _get_outdated_modules(modules):
+        print(mod2)
+
+
 def _get_modules_since_git_sha(sha):
     from .odoo_config import MANIFEST
 
@@ -1523,7 +1561,6 @@ def _get_changed_modules(git_sha):
     modules = []
     root = Path(os.getcwd())
     for filepath in filepaths:
-
         filepath = root / filepath
 
         try:
@@ -1535,5 +1572,55 @@ def _get_changed_modules(git_sha):
     return list(sorted(set(modules)))
 
 
+@odoo_module.command
+@click.option("-f", "--fix-not-in-manifest", is_flag=True)
+@click.option("--only-customs", is_flag=True)
+@pass_config
+def list_installed_modules(config, fix_not_in_manifest, only_customs):
+    from .module_tools import DBModules, Module
+    from .module_tools import NotInAddonsPath
+    from .odoo_config import customs_dir
+    from .odoo_config import MANIFEST
+
+    collected = []
+    not_in_manifest = []
+    manifest = MANIFEST()
+    setinstall = manifest.get("install", [])
+
+    for module in sorted(DBModules.get_all_installed_modules()):
+        try:
+            mod = Module.get_by_name(module)
+        except (Module.IsNot, NotInAddonsPath):
+            click.secho(f"Ignoring {module} - not found in source", fg="yellow")
+            continue
+        if only_customs:
+            try:
+                parts = mod.path.parts
+            except Module.IsNot:
+                click.secho(f"Ignoring {module} - not found in source", fg="yellow")
+                continue
+            if any(x in parts for x in ["odoo", "enterprise", "themes"]):
+                continue
+        try:
+            click.secho(f"{module}: {mod.path}", fg="green")
+            if not [x for x in setinstall if x == module]:
+                not_in_manifest.append(module)
+        except KeyError:
+            collected.append(module)
+
+    for module in not_in_manifest:
+        if fix_not_in_manifest:
+            setinstall += [module]
+            click.secho(f"Added to manifest: {module}", fg="green")
+        else:
+            click.secho(f"Not in MANIFEST: {module}", fg="yellow")
+    for module in collected:
+        click.secho(f"Not in filesystem: {module}", fg="red")
+
+    if fix_not_in_manifest:
+        manifest["install"] = setinstall
+        manifest.rewrite()
+
+
 Commands.register(update)
 Commands.register(show_install_state)
